@@ -163,6 +163,8 @@ errno_from_error (GError *error)
       { G_IO_ERROR_TIMED_OUT,          EIO          },
       { G_IO_ERROR_BUSY,               EBUSY        },
       { G_IO_ERROR_WOULD_BLOCK,        EAGAIN       },
+      { G_IO_ERROR_WOULD_RECURSE,      EXDEV        },
+      { G_IO_ERROR_WOULD_MERGE,        ENOTEMPTY    },
       { -1,                            -1           }
     };
 
@@ -1649,12 +1651,6 @@ vfs_rename (const gchar *old_path, const gchar *new_path)
           g_mutex_unlock (&fh->mutex);
           file_handle_unref (fh);
         }
-
-      if (result == -EISDIR)
-        {
-          /* This makes e.g. 'mv' fall back to a recursive copy + delete operation */
-          result = -EXDEV;
-        }
     }
   else
     {
